"""
identical_meshes
================
"""
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs, _modify_output_spec_with_one_type
from ansys.dpf.core.operators.specification import PinSpecification, Specification

"""Operators from Ans.Dpf.Native plugin, from "logic" category
"""

class identical_meshes(Operator):
    """Take two meshes and compare them.

      available inputs:
        - meshA (MeshedRegion)
        - meshB (MeshedRegion)
        - small_value (float)
        - tolerance (float)

      available outputs:
        - are_identical (bool)

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> # Instantiate operator
      >>> op = dpf.operators.logic.identical_meshes()

      >>> # Make input connections
      >>> my_meshA = dpf.MeshedRegion()
      >>> op.inputs.meshA.connect(my_meshA)
      >>> my_meshB = dpf.MeshedRegion()
      >>> op.inputs.meshB.connect(my_meshB)
      >>> my_small_value = float()
      >>> op.inputs.small_value.connect(my_small_value)
      >>> my_tolerance = float()
      >>> op.inputs.tolerance.connect(my_tolerance)

      >>> # Instantiate operator and connect inputs in one line
      >>> op = dpf.operators.logic.identical_meshes(meshA=my_meshA,meshB=my_meshB,small_value=my_small_value,tolerance=my_tolerance)

      >>> # Get output data
      >>> result_are_identical = op.outputs.are_identical()"""
    def __init__(self, meshA=None, meshB=None, small_value=None, tolerance=None, config=None, server=None):
        super().__init__(name="compare::mesh", config = config, server = server)
        self._inputs = InputsIdenticalMeshes(self)
        self._outputs = OutputsIdenticalMeshes(self)
        if meshA !=None:
            self.inputs.meshA.connect(meshA)
        if meshB !=None:
            self.inputs.meshB.connect(meshB)
        if small_value !=None:
            self.inputs.small_value.connect(small_value)
        if tolerance !=None:
            self.inputs.tolerance.connect(tolerance)

    @staticmethod
    def _spec():
        spec = Specification(description="""Take two meshes and compare them.""",
                             map_input_pin_spec={
                                 0 : PinSpecification(name = "meshA", type_names=["abstract_meshed_region"], optional=False, document=""""""), 
                                 1 : PinSpecification(name = "meshB", type_names=["abstract_meshed_region"], optional=False, document=""""""), 
                                 2 : PinSpecification(name = "small_value", type_names=["double"], optional=False, document="""define what is a small value for numeric comparison."""), 
                                 3 : PinSpecification(name = "tolerance", type_names=["double"], optional=False, document="""define the relative tolerance ceil for numeric comparison.""")},
                             map_output_pin_spec={
                                 0 : PinSpecification(name = "are_identical", type_names=["bool"], optional=False, document="""""")})
        return spec


    @staticmethod
    def default_config():
        return Operator.default_config(name = "compare::mesh")

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsIdenticalMeshes 
        """
        return super().inputs


    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluationg it

        Returns
        --------
        outputs : OutputsIdenticalMeshes 
        """
        return super().outputs


#internal name: compare::mesh
#scripting name: identical_meshes
class InputsIdenticalMeshes(_Inputs):
    """Intermediate class used to connect user inputs to identical_meshes operator

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.logic.identical_meshes()
      >>> my_meshA = dpf.MeshedRegion()
      >>> op.inputs.meshA.connect(my_meshA)
      >>> my_meshB = dpf.MeshedRegion()
      >>> op.inputs.meshB.connect(my_meshB)
      >>> my_small_value = float()
      >>> op.inputs.small_value.connect(my_small_value)
      >>> my_tolerance = float()
      >>> op.inputs.tolerance.connect(my_tolerance)
    """
    def __init__(self, op: Operator):
        super().__init__(identical_meshes._spec().inputs, op)
        self._meshA = Input(identical_meshes._spec().input_pin(0), 0, op, -1) 
        self._inputs.append(self._meshA)
        self._meshB = Input(identical_meshes._spec().input_pin(1), 1, op, -1) 
        self._inputs.append(self._meshB)
        self._small_value = Input(identical_meshes._spec().input_pin(2), 2, op, -1) 
        self._inputs.append(self._small_value)
        self._tolerance = Input(identical_meshes._spec().input_pin(3), 3, op, -1) 
        self._inputs.append(self._tolerance)

    @property
    def meshA(self):
        """Allows to connect meshA input to the operator

        Parameters
        ----------
        my_meshA : MeshedRegion, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.logic.identical_meshes()
        >>> op.inputs.meshA.connect(my_meshA)
        >>> #or
        >>> op.inputs.meshA(my_meshA)

        """
        return self._meshA

    @property
    def meshB(self):
        """Allows to connect meshB input to the operator

        Parameters
        ----------
        my_meshB : MeshedRegion, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.logic.identical_meshes()
        >>> op.inputs.meshB.connect(my_meshB)
        >>> #or
        >>> op.inputs.meshB(my_meshB)

        """
        return self._meshB

    @property
    def small_value(self):
        """Allows to connect small_value input to the operator

        - pindoc: define what is a small value for numeric comparison.

        Parameters
        ----------
        my_small_value : float, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.logic.identical_meshes()
        >>> op.inputs.small_value.connect(my_small_value)
        >>> #or
        >>> op.inputs.small_value(my_small_value)

        """
        return self._small_value

    @property
    def tolerance(self):
        """Allows to connect tolerance input to the operator

        - pindoc: define the relative tolerance ceil for numeric comparison.

        Parameters
        ----------
        my_tolerance : float, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.logic.identical_meshes()
        >>> op.inputs.tolerance.connect(my_tolerance)
        >>> #or
        >>> op.inputs.tolerance(my_tolerance)

        """
        return self._tolerance

class OutputsIdenticalMeshes(_Outputs):
    """Intermediate class used to get outputs from identical_meshes operator
      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.logic.identical_meshes()
      >>> # Connect inputs : op.inputs. ...
      >>> result_are_identical = op.outputs.are_identical()
    """
    def __init__(self, op: Operator):
        super().__init__(identical_meshes._spec().outputs, op)
        self._are_identical = Output(identical_meshes._spec().output_pin(0), 0, op) 
        self._outputs.append(self._are_identical)

    @property
    def are_identical(self):
        """Allows to get are_identical output of the operator


        Returns
        ----------
        my_are_identical : bool, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.logic.identical_meshes()
        >>> # Connect inputs : op.inputs. ...
        >>> result_are_identical = op.outputs.are_identical() 
        """
        return self._are_identical




"""
cyclic_mesh_expansion
=====================
"""
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs, _modify_output_spec_with_one_type
from ansys.dpf.core.operators.specification import PinSpecification, Specification

"""Operators from Ans.Dpf.FEMutils plugin, from "metadata" category
"""

class cyclic_mesh_expansion(Operator):
    """Expand the mesh.

      available inputs:
        - sector_meshed_region (MeshedRegion, MeshesContainer) (optional)
        - cyclic_support (CyclicSupport)
        - sectors_to_expand (list, Scoping, ScopingsContainer) (optional)

      available outputs:
        - meshed_region (MeshedRegion)
        - cyclic_support (CyclicSupport)

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> # Instantiate operator
      >>> op = dpf.operators.metadata.cyclic_mesh_expansion()

      >>> # Make input connections
      >>> my_sector_meshed_region = dpf.MeshedRegion()
      >>> op.inputs.sector_meshed_region.connect(my_sector_meshed_region)
      >>> my_cyclic_support = dpf.CyclicSupport()
      >>> op.inputs.cyclic_support.connect(my_cyclic_support)
      >>> my_sectors_to_expand = dpf.list()
      >>> op.inputs.sectors_to_expand.connect(my_sectors_to_expand)

      >>> # Instantiate operator and connect inputs in one line
      >>> op = dpf.operators.metadata.cyclic_mesh_expansion(sector_meshed_region=my_sector_meshed_region,cyclic_support=my_cyclic_support,sectors_to_expand=my_sectors_to_expand)

      >>> # Get output data
      >>> result_meshed_region = op.outputs.meshed_region()
      >>> result_cyclic_support = op.outputs.cyclic_support()"""
    def __init__(self, sector_meshed_region=None, cyclic_support=None, sectors_to_expand=None, config=None, server=None):
        super().__init__(name="cyclic_expansion_mesh", config = config, server = server)
        self._inputs = InputsCyclicMeshExpansion(self)
        self._outputs = OutputsCyclicMeshExpansion(self)
        if sector_meshed_region !=None:
            self.inputs.sector_meshed_region.connect(sector_meshed_region)
        if cyclic_support !=None:
            self.inputs.cyclic_support.connect(cyclic_support)
        if sectors_to_expand !=None:
            self.inputs.sectors_to_expand.connect(sectors_to_expand)

    @staticmethod
    def _spec():
        spec = Specification(description="""Expand the mesh.""",
                             map_input_pin_spec={
                                 7 : PinSpecification(name = "sector_meshed_region", type_names=["abstract_meshed_region","meshes_container"], optional=True, document=""""""), 
                                 16 : PinSpecification(name = "cyclic_support", type_names=["cyclic_support"], optional=False, document=""""""), 
                                 18 : PinSpecification(name = "sectors_to_expand", type_names=["vector<int32>","scoping","scopings_container"], optional=True, document="""sectors to expand (start at 0), for multistage: use scopings container with 'stage' label.""")},
                             map_output_pin_spec={
                                 0 : PinSpecification(name = "meshed_region", type_names=["abstract_meshed_region"], optional=False, document="""expanded meshed region."""), 
                                 1 : PinSpecification(name = "cyclic_support", type_names=["cyclic_support"], optional=False, document="""input cyclic support modified in place containing the new expanded meshed regions.""")})
        return spec


    @staticmethod
    def default_config():
        return Operator.default_config(name = "cyclic_expansion_mesh")

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsCyclicMeshExpansion 
        """
        return super().inputs


    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluationg it

        Returns
        --------
        outputs : OutputsCyclicMeshExpansion 
        """
        return super().outputs


#internal name: cyclic_expansion_mesh
#scripting name: cyclic_mesh_expansion
class InputsCyclicMeshExpansion(_Inputs):
    """Intermediate class used to connect user inputs to cyclic_mesh_expansion operator

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.metadata.cyclic_mesh_expansion()
      >>> my_sector_meshed_region = dpf.MeshedRegion()
      >>> op.inputs.sector_meshed_region.connect(my_sector_meshed_region)
      >>> my_cyclic_support = dpf.CyclicSupport()
      >>> op.inputs.cyclic_support.connect(my_cyclic_support)
      >>> my_sectors_to_expand = dpf.list()
      >>> op.inputs.sectors_to_expand.connect(my_sectors_to_expand)
    """
    def __init__(self, op: Operator):
        super().__init__(cyclic_mesh_expansion._spec().inputs, op)
        self._sector_meshed_region = Input(cyclic_mesh_expansion._spec().input_pin(7), 7, op, -1) 
        self._inputs.append(self._sector_meshed_region)
        self._cyclic_support = Input(cyclic_mesh_expansion._spec().input_pin(16), 16, op, -1) 
        self._inputs.append(self._cyclic_support)
        self._sectors_to_expand = Input(cyclic_mesh_expansion._spec().input_pin(18), 18, op, -1) 
        self._inputs.append(self._sectors_to_expand)

    @property
    def sector_meshed_region(self):
        """Allows to connect sector_meshed_region input to the operator

        Parameters
        ----------
        my_sector_meshed_region : MeshedRegion, MeshesContainer, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.metadata.cyclic_mesh_expansion()
        >>> op.inputs.sector_meshed_region.connect(my_sector_meshed_region)
        >>> #or
        >>> op.inputs.sector_meshed_region(my_sector_meshed_region)

        """
        return self._sector_meshed_region

    @property
    def cyclic_support(self):
        """Allows to connect cyclic_support input to the operator

        Parameters
        ----------
        my_cyclic_support : CyclicSupport, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.metadata.cyclic_mesh_expansion()
        >>> op.inputs.cyclic_support.connect(my_cyclic_support)
        >>> #or
        >>> op.inputs.cyclic_support(my_cyclic_support)

        """
        return self._cyclic_support

    @property
    def sectors_to_expand(self):
        """Allows to connect sectors_to_expand input to the operator

        - pindoc: sectors to expand (start at 0), for multistage: use scopings container with 'stage' label.

        Parameters
        ----------
        my_sectors_to_expand : list, Scoping, ScopingsContainer, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.metadata.cyclic_mesh_expansion()
        >>> op.inputs.sectors_to_expand.connect(my_sectors_to_expand)
        >>> #or
        >>> op.inputs.sectors_to_expand(my_sectors_to_expand)

        """
        return self._sectors_to_expand

class OutputsCyclicMeshExpansion(_Outputs):
    """Intermediate class used to get outputs from cyclic_mesh_expansion operator
      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.metadata.cyclic_mesh_expansion()
      >>> # Connect inputs : op.inputs. ...
      >>> result_meshed_region = op.outputs.meshed_region()
      >>> result_cyclic_support = op.outputs.cyclic_support()
    """
    def __init__(self, op: Operator):
        super().__init__(cyclic_mesh_expansion._spec().outputs, op)
        self._meshed_region = Output(cyclic_mesh_expansion._spec().output_pin(0), 0, op) 
        self._outputs.append(self._meshed_region)
        self._cyclic_support = Output(cyclic_mesh_expansion._spec().output_pin(1), 1, op) 
        self._outputs.append(self._cyclic_support)

    @property
    def meshed_region(self):
        """Allows to get meshed_region output of the operator


        - pindoc: expanded meshed region.

        Returns
        ----------
        my_meshed_region : MeshedRegion, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.metadata.cyclic_mesh_expansion()
        >>> # Connect inputs : op.inputs. ...
        >>> result_meshed_region = op.outputs.meshed_region() 
        """
        return self._meshed_region

    @property
    def cyclic_support(self):
        """Allows to get cyclic_support output of the operator


        - pindoc: input cyclic support modified in place containing the new expanded meshed regions.

        Returns
        ----------
        my_cyclic_support : CyclicSupport, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.metadata.cyclic_mesh_expansion()
        >>> # Connect inputs : op.inputs. ...
        >>> result_cyclic_support = op.outputs.cyclic_support() 
        """
        return self._cyclic_support




"""
TimeFreqSupport
===============
"""
from ansys import dpf
from ansys.dpf import core
from ansys.dpf.core import errors as dpf_errors
from ansys.dpf.core.errors import protect_grpc
from ansys.grpc.dpf import (
    base_pb2,
    support_pb2,
    time_freq_support_pb2,
    time_freq_support_pb2_grpc,
)


class TimeFreqSupport:
    """Represents a time frequency support, which is a description of a temporal or frequency analysis.

    This class stores values such as the frequencies (time/complex), RPMs, and harmonic indices.
    The RPM value is a step (or load step)-based value.
    The time freqencies, complex frequencies, and harmonic indices are set-based values.
    There is one set value for each step/substep combination.

    Parameters
    ----------
    time_freq_support : ansys.grpc.dpf.time_freq_support_pb2.TimeFreqSupport
    server : ansys.dpf.core.server, optional
        Server with the channel connected to the remote or local instance.
        The default is ``None``, in which case an attempt is made to use the
        global server.

    Examples
    --------
    Create a time frequency support from a model.

    >>> from ansys.dpf.core import Model
    >>> from ansys.dpf.core import examples
    >>> transient = examples.download_transient_result()
    >>> model = Model(transient)
    >>> time_freq_support = model.metadata.time_freq_support # printable

    """

    def __init__(self, time_freq_support=None, server=None):
        """Initialize the TimeFreqSupport with its TimeFreqSupport message (if possible)."""
        if server is None:
            server = dpf.core._global_server()

        self._server = server
        self._stub = self._connect()
        if isinstance(time_freq_support, time_freq_support_pb2.TimeFreqSupport):
            self._message = time_freq_support
        elif isinstance(time_freq_support, support_pb2.Support):
            self._message = time_freq_support_pb2.TimeFreqSupport()
            self._message.id = time_freq_support.id
        else:
            request = base_pb2.Empty()
            self._message = self._stub.Create(request)

    def __str__(self):
        """Describe the entity.

        Returns
        -------
        description : str
        """
        from ansys.dpf.core.core import _description

        return _description(self._message, self._server)

    @property
    def time_frequencies(self):
        """Field of time frequencies or time values for the active result.
        Frequencies field can have one value by set.

        Examples
        --------
        >>> from ansys.dpf.core import Model
        >>> from ansys.dpf.core import examples
        >>> transient = examples.download_transient_result()
        >>> model = Model(transient)
        >>> time_freq_support = model.metadata.time_freq_support
        >>> freq = time_freq_support.time_frequencies
        >>> freq.data
        array([0.        , 0.019975  , 0.039975  , 0.059975  , 0.079975  ,
               0.099975  , 0.119975  , 0.139975  , 0.159975  , 0.179975  ,
               0.199975  , 0.218975  , 0.238975  , 0.258975  , 0.278975  ,
               0.298975  , 0.318975  , 0.338975  , 0.358975  , 0.378975  ,
               0.398975  , 0.417975  , 0.437975  , 0.457975  , 0.477975  ,
               0.497975  , 0.517975  , 0.53754972, 0.55725277, 0.57711786,
               0.59702054, 0.61694639, 0.63683347, 0.65673452, 0.67662783])

        """
        return self._get_frequencies()

    def _set_time_frequencies(self, frequencies):
        """Set the time frequencies of the time_freq_support.
        Frequencies field can have one value by set.

        Parameters
        ----------
        frequencies: Field
            Field of time frequencies that must be set.
        """
        request = time_freq_support_pb2.TimeFreqSupportUpdateRequest()
        request.time_freq_support.CopyFrom(self._message)
        request.freq_real.CopyFrom(frequencies._message)
        self._stub.Update(request)

    @time_frequencies.setter
    def time_frequencies(self, value):
        """Time frequencies that define the time_freq_support of the analysis.
        Frequencies field can have one value by set.

        Parameters
        ----------
        value : Field
            Field of time frequencies that must be set.
        """
        return self._set_time_frequencies(value)

    @property
    def complex_frequencies(self):
        """Field of complex frequencies for the active result.
        Complex frequencies field can have one value by set.

        Examples
        --------
        >>> from ansys.dpf.core import Model
        >>> from ansys.dpf.core import examples
        >>> transient = examples.download_transient_result()
        >>> model = Model(transient)
        >>> time_freq_support = model.metadata.time_freq_support
        >>> freq = time_freq_support.complex_frequencies

        """
        return self._get_frequencies(cplx=True)

    def _set_complex_frequencies(self, complex_frequencies):
        """Set the frequencies of the time_freq_support.
        Complex frequencies field can have one value by set.

        Parameters
        ----------
        complex_frequencies : Field
            Field of frequencies that must be set.
        """
        request = time_freq_support_pb2.TimeFreqSupportUpdateRequest()
        request.time_freq_support.CopyFrom(self._message)
        request.freq_complex.CopyFrom(complex_frequencies._message)
        self._stub.Update(request)

    @complex_frequencies.setter
    def complex_frequencies(self, value):
        """Complex frequencies that define the time_freq_support of the analysis.
        Complex frequencies field can have one value by set.

        Parameters
        ----------
        value : Field
            Field of complex frequencies that must be set.
        """
        return self._set_complex_frequencies(value)

    @property
    def rpms(self):
        """Field of RPMs for the active result.
        The RPM field has one value by load step.

        Returns ``None`` if the result has no RPMs.
        """
        return self._get_rpms()

    def _set_rpms(self, rpms):
        """Set the RPMs values of the time_freq_support.
        RPMs field has one value by load step.

        Parameters
        ----------
        rpms : Field
            Field of RPMs that must be set.
        """
        request = time_freq_support_pb2.TimeFreqSupportUpdateRequest()
        request.time_freq_support.CopyFrom(self._message)
        request.rpm.CopyFrom(rpms._message)
        self._stub.Update(request)

    @rpms.setter
    def rpms(self, value):
        """RPMs that define the time_freq_support of the analysis.
        RPMs field has one value by load step.

        Parameters
        ----------
        value : Field
            Field of RPMs that must be set.
        """
        return self._set_rpms(value)

    def get_harmonic_indices(self, stage_num=0):
        """Retrieve the field of harmonic indices for the active result.

        Returns
        -------
        field : dpf.core.Field
            Field of all harmonic indices in the model (complex or
            real).  ``None`` if result is not cyclic and contains no
            harmonic indices.

        stage_num: int, default: 0, optional
            Targeted stage number.

        """
        return self._get_harmonic_indices(stage_num)

    def set_harmonic_indices(self, harmonic_indices, stage_num=0):
        """Set the harmonic indices values of the time frequency support.

        Parameters
        ----------
        harmonic_indices : Field
            Field of harmonic indices that must be set.
        stage_num: int, default: 0, optional
            Stage number that is defined by these harmonic indices.
        """
        request = time_freq_support_pb2.TimeFreqSupportUpdateRequest()
        cyclic_data = time_freq_support_pb2.CyclicHarmonicData()
        request.time_freq_support.CopyFrom(self._message)
        cyclic_data.cyc_harmonic_index.CopyFrom(harmonic_indices._message)
        cyclic_data.stage_num = stage_num
        request.cyc_harmonic_data.CopyFrom(cyclic_data)
        self._stub.Update(request)

    @property
    def n_sets(self):
        """Number of result sets.

        Examples
        --------
        >>> from ansys.dpf.core import Model
        >>> from ansys.dpf.core import examples
        >>> transient = examples.download_transient_result()
        >>> model = Model(transient)
        >>> time_freq_support = model.metadata.time_freq_support
        >>> time_freq_support.n_sets
        35

        """
        return self._sets_count()

    def get_frequency(self, step=0, substep=0, cumulative_index=None, cplx=False):
        """Retrieve the frequence corresponding to a requested step/substep or
        cumulative index.

        Parameters
        ----------
        step : int, optional
            Index of the step (one-based).
        substep : int, optional
            Index of the substep (one-based).
        cumulative_index : int, optional
            Cumulative index (one-based).
        cplx: bool
            Whether to return a complex frequency. The  default is ``False``.

        Returns
        -------
        frequency : double
            Frequency of the step or substep.
        """
        return self._get_frequency(step, substep, cumulative_index, cplx)

    @protect_grpc
    def _get_frequency(self, step, substep, cumulative_index, cplx):
        """Retrieves the frequence corresponding to the requested step/substep or
        cumulative index.
        """
        request = time_freq_support_pb2.GetRequest()
        request.time_freq_support.CopyFrom(self._message)
        request.complex = cplx
        # request.complex = base_pb2.Complex.Value(cplx)
        if cumulative_index is None:
            request.step_substep.step = step
            request.step_substep.substep = substep
        else:
            request.cumulative_index = cumulative_index
        return self._stub.Get(request).frequency

    def get_cumulative_index(self, step=0, substep=0, freq=None, cplx=False):
        """Retrieves the cumulative index corresponding to the requested step/substep
        or frequency.

        Parameters
        ----------
        step : int, optional
            Analysis step.
        substep : int, optional
            Analysis substep.
        freq  : double, optional
            Frequency in Hz.
        cplx : False, optional
            Whehter to return a complex frequency. The default is ``False``.

        Returns
        -------
        index : int
            Cumulative index based on either the step, substep, or
            frequency.
        """
        return self._get_cumulative_index(step, substep, freq, cplx)

    @protect_grpc
    def _get_cumulative_index(self, step, substep, freq, cplx):
        """Retrieve the cumulative index corresponding to the requested step/substep
        or frequency."""
        request = time_freq_support_pb2.GetRequest()
        request.time_freq_support.CopyFrom(self._message)
        request.bool_cumulative_index = True
        request.complex = cplx
        if freq is not None:
            request.frequency = freq
        else:
            request.step_substep.step = step
            request.step_substep.substep = substep
        return self._stub.Get(request).cumulative_index

    @protect_grpc
    def _sets_count(self):
        """
        Returns
        -------
        count : int
        """
        request = time_freq_support_pb2.CountRequest()
        request.time_freq_support.CopyFrom(self._message)
        request.entity = base_pb2.NUM_SETS
        return self._stub.Count(request).count

    @protect_grpc
    def _get_frequencies(self, cplx=False):
        """Retrieves a field of all the frequencies in the model
        (complex or real).

        Parameters
        ----------
        cplx : bool, optional
            Whether to return a complex frequency. The default ``False``.

        Returns
        -------
        field : dpf.core.Field
            Field of all the frequencies in the model (complex or real).
        """
        request = time_freq_support_pb2.ListRequest()
        request.time_freq_support.CopyFrom(self._message)

        list_response = self._stub.List(request)
        if cplx is True and list_response.freq_complex.id != 0:
            return dpf.core.Field(server=self._server, field=list_response.freq_complex)
        elif cplx is False and list_response.freq_real.id != 0:
            return dpf.core.Field(server=self._server, field=list_response.freq_real)
        return None

    @protect_grpc
    def _get_rpms(self):
        """Retrieves a field of all the RPMs in the model.

        Returns
        -------
        field : dpf.core.Field
            Field of all the RPMs in the model (complex or real).
        """
        request = time_freq_support_pb2.ListRequest()
        request.time_freq_support.CopyFrom(self._message)

        list_response = self._stub.List(request)
        if list_response.rpm.id != 0:
            return dpf.core.Field(server=self._server, field=list_response.rpm)
        return None

    @protect_grpc
    def _get_harmonic_indices(self, stage_num=0):
        """Retrieves a field of all the harmonic indices in the model.

        Returns
        -------
        field : dpf.core.Field
            Field of all the harmonic indices in the model (complex or real).

        stage_num: int, optional, default = 0
            Targeted stage number.
        """
        request = time_freq_support_pb2.ListRequest()
        request.time_freq_support.CopyFrom(self._message)
        request.cyclic_stage_num = stage_num

        list_response = self._stub.List(request)
        if list_response.cyc_harmonic_index.id != 0:
            return dpf.core.Field(
                server=self._server, field=list_response.cyc_harmonic_index
            )
        return None

    def append_step(
        self,
        step_id,
        step_time_frequencies,
        step_complex_frequencies=None,
        rpm_value=None,
        step_harmonic_indices=None,
    ):
        """Append a step with all its field values in the time frequencies support.
        The RPM value is a step (or load step)-based value.
        The values for time freqencies, complex frequencies, and harmonic indices are set-based.
        There is one set value for each step/substep combination.

        It is necessary that each call of my_time_freq_support.append_step(kwargs**) contains
        the same arguments.

        It is necessary that time_frequencies/complex_frequencies/harmonic_indices lists have
        the same size if specified in the same my_time_freq_support.append_step(kwargs**) call.

        Parameters
        ----------
        step_id: int
            ID of the step to add.
        step_time_frequencies: list of int/float
            Values for time frequencies related to the specified step.
        step_complex_frequencies: list of int/float, optional
            Values for complex frequencies related to the specified step.
        rpm_value: int/float, optional
            Value for RPM value for the specified step.
        step_harmonic_indices: optional, dictionary or list
            Dictionary of ``{ int : list of int/float } = { stage_num : harmonic_indices }``
            or a list of int/float. In this case, stage_num default value is 0.
            Harmonic indices are values related to the specified step.

        Example
        -------
        >>> from ansys.dpf.core import TimeFreqSupport

        >>> tfq = TimeFreqSupport()
        >>> tfq.append_step(1, [0.1, 0.21, 1.0], rpm_value = 2.0)
        >>> tfq.append_step(2, [1.1, 2.0], rpm_value = 2.3)

        >>> tfq2 = TimeFreqSupport()
        >>> tfq2.append_step(1, [0.1, 0.21, 1.0], rpm_value = 2.0, step_harmonic_indices = [1.0, 2.0, 3.0])
        >>> tfq2.append_step(2, [1.1, 2.0], rpm_value = 2.3, step_harmonic_indices = [1.0, 2.0])
        >>> tfq2.append_step(3, [0.23, 0.25], rpm_value = 3.0, step_harmonic_indices = [1.0, 2.0])

        >>> tfq3 = TimeFreqSupport()
        >>> tfq3.append_step(1, [0.1, 0.21, 1.0], rpm_value = 2.0, step_harmonic_indices = {1: [1.0, 2.0, 3.0], 2: [1.0, 2.0, 2.5]})

        """  # noqa: E501

        time_frequencies = self.time_frequencies
        if time_frequencies is None:
            time_frequencies = core.Field(
                server=self._server,
                nature=core.natures.scalar,
                location=core.locations.time_freq,
            )
            time_frequencies.scoping.location = core.locations.time_freq_step
        time_frequencies.append(step_time_frequencies, step_id)
        self.time_frequencies = time_frequencies

        if step_complex_frequencies is not None:
            complex_frequencies = self.complex_frequencies
            if complex_frequencies is None:
                complex_frequencies = core.Field(
                    server=self._server,
                    nature=core.natures.scalar,
                    location=core.locations.time_freq,
                )
                complex_frequencies.scoping.location = core.locations.time_freq_step
            complex_frequencies.append(step_complex_frequencies, step_id)
            self.complex_frequencies = complex_frequencies

        if rpm_value is not None:
            rpms = self.rpms
            if rpms is None:
                rpms = core.Field(
                    server=self._server,
                    nature=core.natures.scalar,
                    location=core.locations.time_freq_step,
                )
            rpms.append([rpm_value], step_id)
            self.rpms = rpms

        if step_harmonic_indices is not None:
            if isinstance(step_harmonic_indices, list):
                self._set_harmonic_indices_at_stage(0, step_harmonic_indices, step_id)
            elif isinstance(step_harmonic_indices, dict):
                for key in step_harmonic_indices:
                    self._set_harmonic_indices_at_stage(
                        key, step_harmonic_indices[key], step_id
                    )
            else:
                raise dpf_errors.InvalidTypeError("list/dict", "step_harmonic_indices")

    def deep_copy(self, server=None):
        """Create a deep copy of the data for a time frequency support on a given server.

        This methos is useful for passing data from one server instance to another.

        Parameters
        ----------
        server : ansys.dpf.core.server, optional
            Server with the channel connected to the remote or local instance.
            The default is ``None``, in which case an attempt is made to use the
            global server.

        Returns
        -------
        tf_copy : TimeFreqSupport
        """
        tf = TimeFreqSupport(server=server)
        tf.time_frequencies = self.time_frequencies.deep_copy(server=server)
        if self.complex_frequencies:
            tf.complex_frequencies = self.complex_frequencies.deep_copy(server=server)
        if self.rpms:
            tf.rpms = self.rpms.deep_copy(server=server)
        i = 0
        while True:
            try:
                tf.set_harmonic_indices(
                    self.get_harmonic_indices(i).deep_copy(server=server), i
                )
                i += 1
            except:
                break
        return tf

    def _set_harmonic_indices_at_stage(self, stage_num, step_harmonic_indices, step_id):
        """Set values for harmonic indices for a specific stage number.

        Parameters
        ----------
        stage_num: int
            Stage number.
         harmonic_indices: list of int or float
            List of values for harmonic indices.
        """
        harmonic_indices = self.get_harmonic_indices(stage_num)
        if harmonic_indices is None:
            harmonic_indices = core.Field(
                server=self._server,
                nature=core.natures.scalar,
                location=core.locations.time_freq,
            )
            harmonic_indices.scoping.location = core.locations.time_freq_step
        harmonic_indices.append(step_harmonic_indices, step_id)
        self.set_harmonic_indices(harmonic_indices, stage_num)

    def _connect(self):
        """Connect to the gRPC service."""
        return time_freq_support_pb2_grpc.TimeFreqSupportServiceStub(
            self._server.channel
        )

    def __del__(self):
        try:
            self._stub.Delete(self._message)
        except:
            pass



"""
python_generator
================
"""
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs, _modify_output_spec_with_one_type
from ansys.dpf.core.operators.specification import PinSpecification, Specification

"""Operators from Ans.Dpf.Native plugin, from "utility" category
"""

class python_generator(Operator):
    """Generates .py file with specifications for loaded plugin(s).

      available inputs:
        - dll_source_path (str)
        - output_path (str)

      available outputs:


      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> # Instantiate operator
      >>> op = dpf.operators.utility.python_generator()

      >>> # Make input connections
      >>> my_dll_source_path = str()
      >>> op.inputs.dll_source_path.connect(my_dll_source_path)
      >>> my_output_path = str()
      >>> op.inputs.output_path.connect(my_output_path)

      >>> # Instantiate operator and connect inputs in one line
      >>> op = dpf.operators.utility.python_generator(dll_source_path=my_dll_source_path,output_path=my_output_path)

      >>> # Get output data"""
    def __init__(self, dll_source_path=None, output_path=None, config=None, server=None):
        super().__init__(name="python_generator", config = config, server = server)
        self._inputs = InputsPythonGenerator(self)
        self._outputs = OutputsPythonGenerator(self)
        if dll_source_path !=None:
            self.inputs.dll_source_path.connect(dll_source_path)
        if output_path !=None:
            self.inputs.output_path.connect(output_path)

    @staticmethod
    def _spec():
        spec = Specification(description="""Generates .py file with specifications for loaded plugin(s).""",
                             map_input_pin_spec={
                                 0 : PinSpecification(name = "dll_source_path", type_names=["string"], optional=False, document=""""""), 
                                 1 : PinSpecification(name = "output_path", type_names=["string"], optional=False, document="""""")},
                             map_output_pin_spec={
})
        return spec


    @staticmethod
    def default_config():
        return Operator.default_config(name = "python_generator")

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsPythonGenerator 
        """
        return super().inputs


    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluationg it

        Returns
        --------
        outputs : OutputsPythonGenerator 
        """
        return super().outputs


#internal name: python_generator
#scripting name: python_generator
class InputsPythonGenerator(_Inputs):
    """Intermediate class used to connect user inputs to python_generator operator

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.utility.python_generator()
      >>> my_dll_source_path = str()
      >>> op.inputs.dll_source_path.connect(my_dll_source_path)
      >>> my_output_path = str()
      >>> op.inputs.output_path.connect(my_output_path)
    """
    def __init__(self, op: Operator):
        super().__init__(python_generator._spec().inputs, op)
        self._dll_source_path = Input(python_generator._spec().input_pin(0), 0, op, -1) 
        self._inputs.append(self._dll_source_path)
        self._output_path = Input(python_generator._spec().input_pin(1), 1, op, -1) 
        self._inputs.append(self._output_path)

    @property
    def dll_source_path(self):
        """Allows to connect dll_source_path input to the operator

        Parameters
        ----------
        my_dll_source_path : str, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.utility.python_generator()
        >>> op.inputs.dll_source_path.connect(my_dll_source_path)
        >>> #or
        >>> op.inputs.dll_source_path(my_dll_source_path)

        """
        return self._dll_source_path

    @property
    def output_path(self):
        """Allows to connect output_path input to the operator

        Parameters
        ----------
        my_output_path : str, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.utility.python_generator()
        >>> op.inputs.output_path.connect(my_output_path)
        >>> #or
        >>> op.inputs.output_path(my_output_path)

        """
        return self._output_path

class OutputsPythonGenerator(_Outputs):
    """Intermediate class used to get outputs from python_generator operator
      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.utility.python_generator()
      >>> # Connect inputs : op.inputs. ...
    """
    def __init__(self, op: Operator):
        super().__init__(python_generator._spec().outputs, op)
        pass 




"""
Operator Configuration
======================
"""

import functools

from ansys import dpf
from ansys.dpf.core.errors import protect_grpc
from ansys.grpc.dpf import operator_config_pb2, operator_config_pb2_grpc


class Config:
    """Represents an operator's configuration.

    You can use configurations to choose how an operator will run.
    This is an advanced feature for deep customization.
    The different options can change the way loops are done.
    They can also change whether the operator needs to perform checks on the input.

    Parameters
    ----------
    operator_name : str, optional
        Name of the operator. The default is ``None``.
    config : str, optional
        Name of the configuration. The default is ``None``.
    server : str, optional
        Server with the channel connected to the remote or local instance. The default is
        ``None``, in which case an attempt is made to use the global server.

    """

    def __init__(self, operator_name=None, config=None, server=None):
        if server is None:
            server = dpf.core._global_server()

        self._server = server

        self._stub = self._connect()

        if config:
            self._message = config
        else:
            self.__send_init_request(operator_name)

        if hasattr(self._message, "spec"):
            self._config_help = self._message.spec

        opt = self.options
        for name in opt:
            bound_method = self.config_option_value.__get__(self, self.__class__)
            method2 = functools.partial(bound_method, config_name=name)
            setattr(self, "get_" + name + "_option", method2)

            bound_method = self.__set_config_option__.__get__(self, self.__class__)
            method2 = functools.partial(bound_method, config_name=name)
            setattr(self, "set_" + name + "_option", method2)

    def _connect(self):
        """Connect to the gRPC service."""
        return operator_config_pb2_grpc.OperatorConfigServiceStub(self._server.channel)

    @protect_grpc
    def __send_init_request(self, operator_name=None):
        request = operator_config_pb2.CreateRequest()
        if operator_name:
            request.operator_name.operator_name = operator_name
        self._message = self._stub.Create(request)

    @property
    def options(self):
        """Retrieve a list of configuration options and their values.

        Returns
        -------
        list
            List of configuration options and their values.
        """
        tmp = self._stub.List(self._message)
        out = {}
        for opt in tmp.options:
            out[opt.option_name] = opt.value_str
        return out

    def __set_config_option__(self, config_value, config_name):
        """Change the value of a configuration option.

        Parameters
        ----------
        config_value : bool, int, float
            Value to give to a configuration option.
         config_name : str
            Name of the configuration option.
        """
        request = operator_config_pb2.UpdateRequest()
        request.config.CopyFrom(self._message)
        option_request = operator_config_pb2.ConfigOption()
        option_request.option_name = config_name
        if isinstance(config_value, bool):
            option_request.bool = config_value
        elif isinstance(config_value, int):
            option_request.int = config_value
        elif isinstance(config_value, float):
            option_request.double = config_value
        else:
            raise TypeError(
                "str, int, float are the accepted types for configuration options."
            )

        request.options.extend([option_request])
        self._stub.Update(request)

    def set_config_option(self, config_name, config_value):
        """Change the value of a configuration option.

        Parameters
        ----------
        config_value : bool, int, float
            Value to give to a configuration option.
         config_name : str
            Name of the configuration option.
        """
        return self.__set_config_option__(config_value, config_name)

    def config_option_value(self, config_name):
        """Retrieve the value for a configuration option.

        Parameters
        ----------
        config_name : str
            Name of the configuration option.

        Returns
        ----------
        str
            Value for the configuration option.
        """
        opt = self.options
        if config_name in opt:
            return opt[config_name]
        else:
            raise KeyError(f"{config_name} option doesn't exist.")

    def __try_get_option__(self, config_name):
        if self._config_help:
            for option in self._config_help.config_options_spec:
                if option.name == config_name:
                    return option
        return None

    def config_option_documentation(self, config_name):
        """Retrieve the documentation for a configuration option.

        Parameters
        ----------
        config_name : str
            Name of the configuration option.

        Returns
        ----------
        str
           Documentation for the configuration option.
        """
        option = self.__try_get_option__(config_name)
        if option:
            return option.document
        return ""

    def config_option_accepted_types(self, config_name):
        """Retrieve accepted types for a configuration option.

        Parameters
        ----------
        config_name : str
            Name of the configuration option.

        Returns
        ----------
        list, str
            One or more accepted types for the configuration option.
        """
        if self._config_help:
            for option in self._config_help.config_options_spec:
                if option.name == config_name:
                    return option.type_names
        return ""

    def config_option_default_value(self, config_name):
        """Retrieve the default value for a configuration option.

        Parameters
        ----------
        config_name : str
            Name of the configuration option.

        Returns
        ----------
        str
            Default value for the configuration option.
        """
        if self._config_help:
            for option in self._config_help.config_options_spec:
                if option.name == config_name:
                    return option.default_value_str
        return ""

    @property
    def available_config_options(self):
        """Available configuration options for the operator.

        Returns
        ----------
        list, str
           One or more available configuration options for the operator.
        """
        tmp = self._stub.List(self._message)
        out = []
        for opt in tmp.options:
            out.append(opt.option_name)
        return out

    def __str__(self):
        """Describe the entity.

        Returns
        -------
        str
            Description of the entity.
        """
        from ansys.dpf.core.core import _description

        return _description(self._message, self._server)



"""
forward_fields_container
========================
"""
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs, _modify_output_spec_with_one_type
from ansys.dpf.core.operators.specification import PinSpecification, Specification

"""Operators from Ans.Dpf.Native plugin, from "utility" category
"""

class forward_fields_container(Operator):
    """Return the input field or fields container.

      available inputs:
        - fields (FieldsContainer, Field)

      available outputs:
        - fields_container (FieldsContainer)

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> # Instantiate operator
      >>> op = dpf.operators.utility.forward_fields_container()

      >>> # Make input connections
      >>> my_fields = dpf.FieldsContainer()
      >>> op.inputs.fields.connect(my_fields)

      >>> # Instantiate operator and connect inputs in one line
      >>> op = dpf.operators.utility.forward_fields_container(fields=my_fields)

      >>> # Get output data
      >>> result_fields_container = op.outputs.fields_container()"""
    def __init__(self, fields=None, config=None, server=None):
        super().__init__(name="forward_fc", config = config, server = server)
        self._inputs = InputsForwardFieldsContainer(self)
        self._outputs = OutputsForwardFieldsContainer(self)
        if fields !=None:
            self.inputs.fields.connect(fields)

    @staticmethod
    def _spec():
        spec = Specification(description="""Return the input field or fields container.""",
                             map_input_pin_spec={
                                 0 : PinSpecification(name = "fields", type_names=["fields_container","field"], optional=False, document="""""")},
                             map_output_pin_spec={
                                 0 : PinSpecification(name = "fields_container", type_names=["fields_container"], optional=False, document="""""")})
        return spec


    @staticmethod
    def default_config():
        return Operator.default_config(name = "forward_fc")

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsForwardFieldsContainer 
        """
        return super().inputs


    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluationg it

        Returns
        --------
        outputs : OutputsForwardFieldsContainer 
        """
        return super().outputs


#internal name: forward_fc
#scripting name: forward_fields_container
class InputsForwardFieldsContainer(_Inputs):
    """Intermediate class used to connect user inputs to forward_fields_container operator

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.utility.forward_fields_container()
      >>> my_fields = dpf.FieldsContainer()
      >>> op.inputs.fields.connect(my_fields)
    """
    def __init__(self, op: Operator):
        super().__init__(forward_fields_container._spec().inputs, op)
        self._fields = Input(forward_fields_container._spec().input_pin(0), 0, op, -1) 
        self._inputs.append(self._fields)

    @property
    def fields(self):
        """Allows to connect fields input to the operator

        Parameters
        ----------
        my_fields : FieldsContainer, Field, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.utility.forward_fields_container()
        >>> op.inputs.fields.connect(my_fields)
        >>> #or
        >>> op.inputs.fields(my_fields)

        """
        return self._fields

class OutputsForwardFieldsContainer(_Outputs):
    """Intermediate class used to get outputs from forward_fields_container operator
      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.utility.forward_fields_container()
      >>> # Connect inputs : op.inputs. ...
      >>> result_fields_container = op.outputs.fields_container()
    """
    def __init__(self, op: Operator):
        super().__init__(forward_fields_container._spec().outputs, op)
        self._fields_container = Output(forward_fields_container._spec().output_pin(0), 0, op) 
        self._outputs.append(self._fields_container)

    @property
    def fields_container(self):
        """Allows to get fields_container output of the operator


        Returns
        ----------
        my_fields_container : FieldsContainer, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.utility.forward_fields_container()
        >>> # Connect inputs : op.inputs. ...
        >>> result_fields_container = op.outputs.fields_container() 
        """
        return self._fields_container




"""
sweeping_phase
==============
"""
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs, _modify_output_spec_with_one_type
from ansys.dpf.core.operators.specification import PinSpecification, Specification

"""Operators from Ans.Dpf.Native plugin, from "math" category
"""

class sweeping_phase(Operator):
    """Shift the phase of a real and an imaginary fields (in 0 and 1) of a given angle (in 3) of unit (in 4).

      available inputs:
        - real_field (Field, FieldsContainer)
        - imaginary_field (Field, FieldsContainer)
        - angle (float)
        - unit_name (str)
        - abs_value (bool)
        - imaginary_part_null (bool)

      available outputs:
        - field (Field)

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> # Instantiate operator
      >>> op = dpf.operators.math.sweeping_phase()

      >>> # Make input connections
      >>> my_real_field = dpf.Field()
      >>> op.inputs.real_field.connect(my_real_field)
      >>> my_imaginary_field = dpf.Field()
      >>> op.inputs.imaginary_field.connect(my_imaginary_field)
      >>> my_angle = float()
      >>> op.inputs.angle.connect(my_angle)
      >>> my_unit_name = str()
      >>> op.inputs.unit_name.connect(my_unit_name)
      >>> my_abs_value = bool()
      >>> op.inputs.abs_value.connect(my_abs_value)
      >>> my_imaginary_part_null = bool()
      >>> op.inputs.imaginary_part_null.connect(my_imaginary_part_null)

      >>> # Instantiate operator and connect inputs in one line
      >>> op = dpf.operators.math.sweeping_phase(real_field=my_real_field,imaginary_field=my_imaginary_field,angle=my_angle,unit_name=my_unit_name,abs_value=my_abs_value,imaginary_part_null=my_imaginary_part_null)

      >>> # Get output data
      >>> result_field = op.outputs.field()"""
    def __init__(self, real_field=None, imaginary_field=None, angle=None, unit_name=None, abs_value=None, imaginary_part_null=None, config=None, server=None):
        super().__init__(name="sweeping_phase", config = config, server = server)
        self._inputs = InputsSweepingPhase(self)
        self._outputs = OutputsSweepingPhase(self)
        if real_field !=None:
            self.inputs.real_field.connect(real_field)
        if imaginary_field !=None:
            self.inputs.imaginary_field.connect(imaginary_field)
        if angle !=None:
            self.inputs.angle.connect(angle)
        if unit_name !=None:
            self.inputs.unit_name.connect(unit_name)
        if abs_value !=None:
            self.inputs.abs_value.connect(abs_value)
        if imaginary_part_null !=None:
            self.inputs.imaginary_part_null.connect(imaginary_part_null)

    @staticmethod
    def _spec():
        spec = Specification(description="""Shift the phase of a real and an imaginary fields (in 0 and 1) of a given angle (in 3) of unit (in 4).""",
                             map_input_pin_spec={
                                 0 : PinSpecification(name = "real_field", type_names=["field","fields_container"], optional=False, document="""field or fields container with only one field is expected"""), 
                                 1 : PinSpecification(name = "imaginary_field", type_names=["field","fields_container"], optional=False, document="""field or fields container with only one field is expected"""), 
                                 2 : PinSpecification(name = "angle", type_names=["double"], optional=False, document=""""""), 
                                 3 : PinSpecification(name = "unit_name", type_names=["string"], optional=False, document="""String Unit"""), 
                                 4 : PinSpecification(name = "abs_value", type_names=["bool"], optional=False, document=""""""), 
                                 5 : PinSpecification(name = "imaginary_part_null", type_names=["bool"], optional=False, document="""if the imaginary part field is empty and this pin is true, then the imaginary part is supposed to be 0 (default is false)""")},
                             map_output_pin_spec={
                                 0 : PinSpecification(name = "field", type_names=["field"], optional=False, document="""""")})
        return spec


    @staticmethod
    def default_config():
        return Operator.default_config(name = "sweeping_phase")

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsSweepingPhase 
        """
        return super().inputs


    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluationg it

        Returns
        --------
        outputs : OutputsSweepingPhase 
        """
        return super().outputs


#internal name: sweeping_phase
#scripting name: sweeping_phase
class InputsSweepingPhase(_Inputs):
    """Intermediate class used to connect user inputs to sweeping_phase operator

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.math.sweeping_phase()
      >>> my_real_field = dpf.Field()
      >>> op.inputs.real_field.connect(my_real_field)
      >>> my_imaginary_field = dpf.Field()
      >>> op.inputs.imaginary_field.connect(my_imaginary_field)
      >>> my_angle = float()
      >>> op.inputs.angle.connect(my_angle)
      >>> my_unit_name = str()
      >>> op.inputs.unit_name.connect(my_unit_name)
      >>> my_abs_value = bool()
      >>> op.inputs.abs_value.connect(my_abs_value)
      >>> my_imaginary_part_null = bool()
      >>> op.inputs.imaginary_part_null.connect(my_imaginary_part_null)
    """
    def __init__(self, op: Operator):
        super().__init__(sweeping_phase._spec().inputs, op)
        self._real_field = Input(sweeping_phase._spec().input_pin(0), 0, op, -1) 
        self._inputs.append(self._real_field)
        self._imaginary_field = Input(sweeping_phase._spec().input_pin(1), 1, op, -1) 
        self._inputs.append(self._imaginary_field)
        self._angle = Input(sweeping_phase._spec().input_pin(2), 2, op, -1) 
        self._inputs.append(self._angle)
        self._unit_name = Input(sweeping_phase._spec().input_pin(3), 3, op, -1) 
        self._inputs.append(self._unit_name)
        self._abs_value = Input(sweeping_phase._spec().input_pin(4), 4, op, -1) 
        self._inputs.append(self._abs_value)
        self._imaginary_part_null = Input(sweeping_phase._spec().input_pin(5), 5, op, -1) 
        self._inputs.append(self._imaginary_part_null)

    @property
    def real_field(self):
        """Allows to connect real_field input to the operator

        - pindoc: field or fields container with only one field is expected

        Parameters
        ----------
        my_real_field : Field, FieldsContainer, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.math.sweeping_phase()
        >>> op.inputs.real_field.connect(my_real_field)
        >>> #or
        >>> op.inputs.real_field(my_real_field)

        """
        return self._real_field

    @property
    def imaginary_field(self):
        """Allows to connect imaginary_field input to the operator

        - pindoc: field or fields container with only one field is expected

        Parameters
        ----------
        my_imaginary_field : Field, FieldsContainer, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.math.sweeping_phase()
        >>> op.inputs.imaginary_field.connect(my_imaginary_field)
        >>> #or
        >>> op.inputs.imaginary_field(my_imaginary_field)

        """
        return self._imaginary_field

    @property
    def angle(self):
        """Allows to connect angle input to the operator

        Parameters
        ----------
        my_angle : float, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.math.sweeping_phase()
        >>> op.inputs.angle.connect(my_angle)
        >>> #or
        >>> op.inputs.angle(my_angle)

        """
        return self._angle

    @property
    def unit_name(self):
        """Allows to connect unit_name input to the operator

        - pindoc: String Unit

        Parameters
        ----------
        my_unit_name : str, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.math.sweeping_phase()
        >>> op.inputs.unit_name.connect(my_unit_name)
        >>> #or
        >>> op.inputs.unit_name(my_unit_name)

        """
        return self._unit_name

    @property
    def abs_value(self):
        """Allows to connect abs_value input to the operator

        Parameters
        ----------
        my_abs_value : bool, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.math.sweeping_phase()
        >>> op.inputs.abs_value.connect(my_abs_value)
        >>> #or
        >>> op.inputs.abs_value(my_abs_value)

        """
        return self._abs_value

    @property
    def imaginary_part_null(self):
        """Allows to connect imaginary_part_null input to the operator

        - pindoc: if the imaginary part field is empty and this pin is true, then the imaginary part is supposed to be 0 (default is false)

        Parameters
        ----------
        my_imaginary_part_null : bool, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.math.sweeping_phase()
        >>> op.inputs.imaginary_part_null.connect(my_imaginary_part_null)
        >>> #or
        >>> op.inputs.imaginary_part_null(my_imaginary_part_null)

        """
        return self._imaginary_part_null

class OutputsSweepingPhase(_Outputs):
    """Intermediate class used to get outputs from sweeping_phase operator
      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.math.sweeping_phase()
      >>> # Connect inputs : op.inputs. ...
      >>> result_field = op.outputs.field()
    """
    def __init__(self, op: Operator):
        super().__init__(sweeping_phase._spec().outputs, op)
        self._field = Output(sweeping_phase._spec().output_pin(0), 0, op) 
        self._outputs.append(self._field)

    @property
    def field(self):
        """Allows to get field output of the operator


        Returns
        ----------
        my_field : Field, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.math.sweeping_phase()
        >>> # Connect inputs : op.inputs. ...
        >>> result_field = op.outputs.field() 
        """
        return self._field




"""
intersect
=========
"""
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs, _modify_output_spec_with_one_type
from ansys.dpf.core.operators.specification import PinSpecification, Specification

"""Operators from Ans.Dpf.Native plugin, from "scoping" category
"""

class intersect(Operator):
    """Intersect 2 scopings and return the intersection and the difference between the intersection and the first scoping.

      available inputs:
        - scopingA (Scoping)
        - scopingB (Scoping)

      available outputs:
        - intersection (Scoping)
        - scopingA_min_intersection (Scoping)

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> # Instantiate operator
      >>> op = dpf.operators.scoping.intersect()

      >>> # Make input connections
      >>> my_scopingA = dpf.Scoping()
      >>> op.inputs.scopingA.connect(my_scopingA)
      >>> my_scopingB = dpf.Scoping()
      >>> op.inputs.scopingB.connect(my_scopingB)

      >>> # Instantiate operator and connect inputs in one line
      >>> op = dpf.operators.scoping.intersect(scopingA=my_scopingA,scopingB=my_scopingB)

      >>> # Get output data
      >>> result_intersection = op.outputs.intersection()
      >>> result_scopingA_min_intersection = op.outputs.scopingA_min_intersection()"""
    def __init__(self, scopingA=None, scopingB=None, config=None, server=None):
        super().__init__(name="scoping::intersect", config = config, server = server)
        self._inputs = InputsIntersect(self)
        self._outputs = OutputsIntersect(self)
        if scopingA !=None:
            self.inputs.scopingA.connect(scopingA)
        if scopingB !=None:
            self.inputs.scopingB.connect(scopingB)

    @staticmethod
    def _spec():
        spec = Specification(description="""Intersect 2 scopings and return the intersection and the difference between the intersection and the first scoping.""",
                             map_input_pin_spec={
                                 0 : PinSpecification(name = "scopingA", type_names=["scoping"], optional=False, document=""""""), 
                                 1 : PinSpecification(name = "scopingB", type_names=["scoping"], optional=False, document="""""")},
                             map_output_pin_spec={
                                 0 : PinSpecification(name = "intersection", type_names=["scoping"], optional=False, document=""""""), 
                                 1 : PinSpecification(name = "scopingA_min_intersection", type_names=["scoping"], optional=False, document="""""")})
        return spec


    @staticmethod
    def default_config():
        return Operator.default_config(name = "scoping::intersect")

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsIntersect 
        """
        return super().inputs


    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluationg it

        Returns
        --------
        outputs : OutputsIntersect 
        """
        return super().outputs


#internal name: scoping::intersect
#scripting name: intersect
class InputsIntersect(_Inputs):
    """Intermediate class used to connect user inputs to intersect operator

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.scoping.intersect()
      >>> my_scopingA = dpf.Scoping()
      >>> op.inputs.scopingA.connect(my_scopingA)
      >>> my_scopingB = dpf.Scoping()
      >>> op.inputs.scopingB.connect(my_scopingB)
    """
    def __init__(self, op: Operator):
        super().__init__(intersect._spec().inputs, op)
        self._scopingA = Input(intersect._spec().input_pin(0), 0, op, -1) 
        self._inputs.append(self._scopingA)
        self._scopingB = Input(intersect._spec().input_pin(1), 1, op, -1) 
        self._inputs.append(self._scopingB)

    @property
    def scopingA(self):
        """Allows to connect scopingA input to the operator

        Parameters
        ----------
        my_scopingA : Scoping, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.scoping.intersect()
        >>> op.inputs.scopingA.connect(my_scopingA)
        >>> #or
        >>> op.inputs.scopingA(my_scopingA)

        """
        return self._scopingA

    @property
    def scopingB(self):
        """Allows to connect scopingB input to the operator

        Parameters
        ----------
        my_scopingB : Scoping, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.scoping.intersect()
        >>> op.inputs.scopingB.connect(my_scopingB)
        >>> #or
        >>> op.inputs.scopingB(my_scopingB)

        """
        return self._scopingB

class OutputsIntersect(_Outputs):
    """Intermediate class used to get outputs from intersect operator
      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.scoping.intersect()
      >>> # Connect inputs : op.inputs. ...
      >>> result_intersection = op.outputs.intersection()
      >>> result_scopingA_min_intersection = op.outputs.scopingA_min_intersection()
    """
    def __init__(self, op: Operator):
        super().__init__(intersect._spec().outputs, op)
        self._intersection = Output(intersect._spec().output_pin(0), 0, op) 
        self._outputs.append(self._intersection)
        self._scopingA_min_intersection = Output(intersect._spec().output_pin(1), 1, op) 
        self._outputs.append(self._scopingA_min_intersection)

    @property
    def intersection(self):
        """Allows to get intersection output of the operator


        Returns
        ----------
        my_intersection : Scoping, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.scoping.intersect()
        >>> # Connect inputs : op.inputs. ...
        >>> result_intersection = op.outputs.intersection() 
        """
        return self._intersection

    @property
    def scopingA_min_intersection(self):
        """Allows to get scopingA_min_intersection output of the operator


        Returns
        ----------
        my_scopingA_min_intersection : Scoping, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.scoping.intersect()
        >>> # Connect inputs : op.inputs. ...
        >>> result_scopingA_min_intersection = op.outputs.scopingA_min_intersection() 
        """
        return self._scopingA_min_intersection




"""
vtk_to_fields
=============
"""
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs, _modify_output_spec_with_one_type
from ansys.dpf.core.operators.specification import PinSpecification, Specification

"""Operators from meshOperatorsCore plugin, from "serialization" category
"""

class vtk_to_fields(Operator):
    """Write a field based on a vtk file.

      available inputs:
        - field_name (str) (optional)
        - streams (StreamsContainer) (optional)
        - data_sources (DataSources)

      available outputs:
        - fields_container (FieldsContainer)

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> # Instantiate operator
      >>> op = dpf.operators.serialization.vtk_to_fields()

      >>> # Make input connections
      >>> my_field_name = str()
      >>> op.inputs.field_name.connect(my_field_name)
      >>> my_streams = dpf.StreamsContainer()
      >>> op.inputs.streams.connect(my_streams)
      >>> my_data_sources = dpf.DataSources()
      >>> op.inputs.data_sources.connect(my_data_sources)

      >>> # Instantiate operator and connect inputs in one line
      >>> op = dpf.operators.serialization.vtk_to_fields(field_name=my_field_name,streams=my_streams,data_sources=my_data_sources)

      >>> # Get output data
      >>> result_fields_container = op.outputs.fields_container()"""
    def __init__(self, field_name=None, streams=None, data_sources=None, config=None, server=None):
        super().__init__(name="vtk::vtk::FieldProvider", config = config, server = server)
        self._inputs = InputsVtkToFields(self)
        self._outputs = OutputsVtkToFields(self)
        if field_name !=None:
            self.inputs.field_name.connect(field_name)
        if streams !=None:
            self.inputs.streams.connect(streams)
        if data_sources !=None:
            self.inputs.data_sources.connect(data_sources)

    @staticmethod
    def _spec():
        spec = Specification(description="""Write a field based on a vtk file.""",
                             map_input_pin_spec={
                                 0 : PinSpecification(name = "field_name", type_names=["string"], optional=True, document="""name of the field in the vtk file"""), 
                                 3 : PinSpecification(name = "streams", type_names=["streams_container"], optional=True, document=""""""), 
                                 4 : PinSpecification(name = "data_sources", type_names=["data_sources"], optional=False, document="""""")},
                             map_output_pin_spec={
                                 0 : PinSpecification(name = "fields_container", type_names=["fields_container"], optional=False, document="""fields_container""")})
        return spec


    @staticmethod
    def default_config():
        return Operator.default_config(name = "vtk::vtk::FieldProvider")

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsVtkToFields 
        """
        return super().inputs


    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluationg it

        Returns
        --------
        outputs : OutputsVtkToFields 
        """
        return super().outputs


#internal name: vtk::vtk::FieldProvider
#scripting name: vtk_to_fields
class InputsVtkToFields(_Inputs):
    """Intermediate class used to connect user inputs to vtk_to_fields operator

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.serialization.vtk_to_fields()
      >>> my_field_name = str()
      >>> op.inputs.field_name.connect(my_field_name)
      >>> my_streams = dpf.StreamsContainer()
      >>> op.inputs.streams.connect(my_streams)
      >>> my_data_sources = dpf.DataSources()
      >>> op.inputs.data_sources.connect(my_data_sources)
    """
    def __init__(self, op: Operator):
        super().__init__(vtk_to_fields._spec().inputs, op)
        self._field_name = Input(vtk_to_fields._spec().input_pin(0), 0, op, -1) 
        self._inputs.append(self._field_name)
        self._streams = Input(vtk_to_fields._spec().input_pin(3), 3, op, -1) 
        self._inputs.append(self._streams)
        self._data_sources = Input(vtk_to_fields._spec().input_pin(4), 4, op, -1) 
        self._inputs.append(self._data_sources)

    @property
    def field_name(self):
        """Allows to connect field_name input to the operator

        - pindoc: name of the field in the vtk file

        Parameters
        ----------
        my_field_name : str, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.serialization.vtk_to_fields()
        >>> op.inputs.field_name.connect(my_field_name)
        >>> #or
        >>> op.inputs.field_name(my_field_name)

        """
        return self._field_name

    @property
    def streams(self):
        """Allows to connect streams input to the operator

        Parameters
        ----------
        my_streams : StreamsContainer, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.serialization.vtk_to_fields()
        >>> op.inputs.streams.connect(my_streams)
        >>> #or
        >>> op.inputs.streams(my_streams)

        """
        return self._streams

    @property
    def data_sources(self):
        """Allows to connect data_sources input to the operator

        Parameters
        ----------
        my_data_sources : DataSources, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.serialization.vtk_to_fields()
        >>> op.inputs.data_sources.connect(my_data_sources)
        >>> #or
        >>> op.inputs.data_sources(my_data_sources)

        """
        return self._data_sources

class OutputsVtkToFields(_Outputs):
    """Intermediate class used to get outputs from vtk_to_fields operator
      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.serialization.vtk_to_fields()
      >>> # Connect inputs : op.inputs. ...
      >>> result_fields_container = op.outputs.fields_container()
    """
    def __init__(self, op: Operator):
        super().__init__(vtk_to_fields._spec().outputs, op)
        self._fields_container = Output(vtk_to_fields._spec().output_pin(0), 0, op) 
        self._outputs.append(self._fields_container)

    @property
    def fields_container(self):
        """Allows to get fields_container output of the operator


        - pindoc: fields_container

        Returns
        ----------
        my_fields_container : FieldsContainer, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.serialization.vtk_to_fields()
        >>> # Connect inputs : op.inputs. ...
        >>> result_fields_container = op.outputs.fields_container() 
        """
        return self._fields_container




import os
import inspect

if os.environ.get("DPF_DOCKER", "").lower() == "true":
    # must pass a path that can be accessed by a docker image with
    # this directory mounted at the repository level for CI
    _module_path = r"/dpf/ansys/dpf/core/examples/"
else:
    _module_path = os.path.dirname(inspect.getfile(inspect.currentframe()))

# this files can be imported with from `ansys.dpf.core import examples`:
simple_bar = os.path.join(_module_path, "ASimpleBar.rst")
static_rst = os.path.join(_module_path, "static.rst")
complex_rst = os.path.join(_module_path, "complex.rst")
multishells_rst = os.path.join(_module_path, "model_with_ns.rst")
electric_therm = os.path.join(_module_path, "rth", "rth_electric.rth")
steady_therm = os.path.join(_module_path, "rth", "rth_steady.rth")
transient_therm = os.path.join(_module_path, "rth", "rth_transient.rth")
msup_transient = os.path.join(_module_path, "msup_transient_plate1.rst")
simple_cyclic = os.path.join(_module_path, "file_cyclic.rst")



"""
cyclic_analytic_seqv_max
========================
"""
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs, _modify_output_spec_with_one_type
from ansys.dpf.core.operators.specification import PinSpecification, Specification

"""Operators from Ans.Dpf.FEMutils plugin, from "result" category
"""

class cyclic_analytic_seqv_max(Operator):
    """Compute the maximum of the Von Mises equivalent stress that can be expected on 360 degrees

      available inputs:
        - time_scoping (Scoping, list) (optional)
        - mesh_scoping (ScopingsContainer, Scoping, list) (optional)
        - fields_container (FieldsContainer)
        - bool_rotate_to_global (bool) (optional)
        - cyclic_support (CyclicSupport)

      available outputs:
        - fields_container (FieldsContainer)

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> # Instantiate operator
      >>> op = dpf.operators.result.cyclic_analytic_seqv_max()

      >>> # Make input connections
      >>> my_time_scoping = dpf.Scoping()
      >>> op.inputs.time_scoping.connect(my_time_scoping)
      >>> my_mesh_scoping = dpf.ScopingsContainer()
      >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
      >>> my_fields_container = dpf.FieldsContainer()
      >>> op.inputs.fields_container.connect(my_fields_container)
      >>> my_bool_rotate_to_global = bool()
      >>> op.inputs.bool_rotate_to_global.connect(my_bool_rotate_to_global)
      >>> my_cyclic_support = dpf.CyclicSupport()
      >>> op.inputs.cyclic_support.connect(my_cyclic_support)

      >>> # Instantiate operator and connect inputs in one line
      >>> op = dpf.operators.result.cyclic_analytic_seqv_max(time_scoping=my_time_scoping,mesh_scoping=my_mesh_scoping,fields_container=my_fields_container,bool_rotate_to_global=my_bool_rotate_to_global,cyclic_support=my_cyclic_support)

      >>> # Get output data
      >>> result_fields_container = op.outputs.fields_container()"""
    def __init__(self, time_scoping=None, mesh_scoping=None, fields_container=None, bool_rotate_to_global=None, cyclic_support=None, config=None, server=None):
        super().__init__(name="cyclic_analytic_stress_eqv_max", config = config, server = server)
        self._inputs = InputsCyclicAnalyticSeqvMax(self)
        self._outputs = OutputsCyclicAnalyticSeqvMax(self)
        if time_scoping !=None:
            self.inputs.time_scoping.connect(time_scoping)
        if mesh_scoping !=None:
            self.inputs.mesh_scoping.connect(mesh_scoping)
        if fields_container !=None:
            self.inputs.fields_container.connect(fields_container)
        if bool_rotate_to_global !=None:
            self.inputs.bool_rotate_to_global.connect(bool_rotate_to_global)
        if cyclic_support !=None:
            self.inputs.cyclic_support.connect(cyclic_support)

    @staticmethod
    def _spec():
        spec = Specification(description="""Compute the maximum of the Von Mises equivalent stress that can be expected on 360 degrees""",
                             map_input_pin_spec={
                                 0 : PinSpecification(name = "time_scoping", type_names=["scoping","vector<int32>"], optional=True, document=""""""), 
                                 1 : PinSpecification(name = "mesh_scoping", type_names=["scopings_container","scoping","vector<int32>"], optional=True, document=""""""), 
                                 2 : PinSpecification(name = "fields_container", type_names=["fields_container"], optional=False, document="""field container with the base and duplicate sectors"""), 
                                 5 : PinSpecification(name = "bool_rotate_to_global", type_names=["bool"], optional=True, document="""default is true"""), 
                                 16 : PinSpecification(name = "cyclic_support", type_names=["cyclic_support"], optional=False, document="""""")},
                             map_output_pin_spec={
                                 0 : PinSpecification(name = "fields_container", type_names=["fields_container"], optional=False, document="""FieldsContainer filled in""")})
        return spec


    @staticmethod
    def default_config():
        return Operator.default_config(name = "cyclic_analytic_stress_eqv_max")

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsCyclicAnalyticSeqvMax 
        """
        return super().inputs


    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluationg it

        Returns
        --------
        outputs : OutputsCyclicAnalyticSeqvMax 
        """
        return super().outputs


#internal name: cyclic_analytic_stress_eqv_max
#scripting name: cyclic_analytic_seqv_max
class InputsCyclicAnalyticSeqvMax(_Inputs):
    """Intermediate class used to connect user inputs to cyclic_analytic_seqv_max operator

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.result.cyclic_analytic_seqv_max()
      >>> my_time_scoping = dpf.Scoping()
      >>> op.inputs.time_scoping.connect(my_time_scoping)
      >>> my_mesh_scoping = dpf.ScopingsContainer()
      >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
      >>> my_fields_container = dpf.FieldsContainer()
      >>> op.inputs.fields_container.connect(my_fields_container)
      >>> my_bool_rotate_to_global = bool()
      >>> op.inputs.bool_rotate_to_global.connect(my_bool_rotate_to_global)
      >>> my_cyclic_support = dpf.CyclicSupport()
      >>> op.inputs.cyclic_support.connect(my_cyclic_support)
    """
    def __init__(self, op: Operator):
        super().__init__(cyclic_analytic_seqv_max._spec().inputs, op)
        self._time_scoping = Input(cyclic_analytic_seqv_max._spec().input_pin(0), 0, op, -1) 
        self._inputs.append(self._time_scoping)
        self._mesh_scoping = Input(cyclic_analytic_seqv_max._spec().input_pin(1), 1, op, -1) 
        self._inputs.append(self._mesh_scoping)
        self._fields_container = Input(cyclic_analytic_seqv_max._spec().input_pin(2), 2, op, -1) 
        self._inputs.append(self._fields_container)
        self._bool_rotate_to_global = Input(cyclic_analytic_seqv_max._spec().input_pin(5), 5, op, -1) 
        self._inputs.append(self._bool_rotate_to_global)
        self._cyclic_support = Input(cyclic_analytic_seqv_max._spec().input_pin(16), 16, op, -1) 
        self._inputs.append(self._cyclic_support)

    @property
    def time_scoping(self):
        """Allows to connect time_scoping input to the operator

        Parameters
        ----------
        my_time_scoping : Scoping, list, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.result.cyclic_analytic_seqv_max()
        >>> op.inputs.time_scoping.connect(my_time_scoping)
        >>> #or
        >>> op.inputs.time_scoping(my_time_scoping)

        """
        return self._time_scoping

    @property
    def mesh_scoping(self):
        """Allows to connect mesh_scoping input to the operator

        Parameters
        ----------
        my_mesh_scoping : ScopingsContainer, Scoping, list, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.result.cyclic_analytic_seqv_max()
        >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
        >>> #or
        >>> op.inputs.mesh_scoping(my_mesh_scoping)

        """
        return self._mesh_scoping

    @property
    def fields_container(self):
        """Allows to connect fields_container input to the operator

        - pindoc: field container with the base and duplicate sectors

        Parameters
        ----------
        my_fields_container : FieldsContainer, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.result.cyclic_analytic_seqv_max()
        >>> op.inputs.fields_container.connect(my_fields_container)
        >>> #or
        >>> op.inputs.fields_container(my_fields_container)

        """
        return self._fields_container

    @property
    def bool_rotate_to_global(self):
        """Allows to connect bool_rotate_to_global input to the operator

        - pindoc: default is true

        Parameters
        ----------
        my_bool_rotate_to_global : bool, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.result.cyclic_analytic_seqv_max()
        >>> op.inputs.bool_rotate_to_global.connect(my_bool_rotate_to_global)
        >>> #or
        >>> op.inputs.bool_rotate_to_global(my_bool_rotate_to_global)

        """
        return self._bool_rotate_to_global

    @property
    def cyclic_support(self):
        """Allows to connect cyclic_support input to the operator

        Parameters
        ----------
        my_cyclic_support : CyclicSupport, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.result.cyclic_analytic_seqv_max()
        >>> op.inputs.cyclic_support.connect(my_cyclic_support)
        >>> #or
        >>> op.inputs.cyclic_support(my_cyclic_support)

        """
        return self._cyclic_support

class OutputsCyclicAnalyticSeqvMax(_Outputs):
    """Intermediate class used to get outputs from cyclic_analytic_seqv_max operator
      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.result.cyclic_analytic_seqv_max()
      >>> # Connect inputs : op.inputs. ...
      >>> result_fields_container = op.outputs.fields_container()
    """
    def __init__(self, op: Operator):
        super().__init__(cyclic_analytic_seqv_max._spec().outputs, op)
        self._fields_container = Output(cyclic_analytic_seqv_max._spec().output_pin(0), 0, op) 
        self._outputs.append(self._fields_container)

    @property
    def fields_container(self):
        """Allows to get fields_container output of the operator


        - pindoc: FieldsContainer filled in

        Returns
        ----------
        my_fields_container : FieldsContainer, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.result.cyclic_analytic_seqv_max()
        >>> # Connect inputs : op.inputs. ...
        >>> result_fields_container = op.outputs.fields_container() 
        """
        return self._fields_container




"""
change_location
===============
"""
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs, _modify_output_spec_with_one_type
from ansys.dpf.core.operators.specification import PinSpecification, Specification

"""Operators from Ans.Dpf.Native plugin, from "utility" category
"""

class change_location(Operator):
    """change the location of a field.

      available inputs:
        - field (Field)
        - new_location (str)

      available outputs:
        - field (Field)

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> # Instantiate operator
      >>> op = dpf.operators.utility.change_location()

      >>> # Make input connections
      >>> my_field = dpf.Field()
      >>> op.inputs.field.connect(my_field)
      >>> my_new_location = str()
      >>> op.inputs.new_location.connect(my_new_location)

      >>> # Instantiate operator and connect inputs in one line
      >>> op = dpf.operators.utility.change_location(field=my_field,new_location=my_new_location)

      >>> # Get output data
      >>> result_field = op.outputs.field()"""
    def __init__(self, field=None, new_location=None, config=None, server=None):
        super().__init__(name="change_location", config = config, server = server)
        self._inputs = InputsChangeLocation(self)
        self._outputs = OutputsChangeLocation(self)
        if field !=None:
            self.inputs.field.connect(field)
        if new_location !=None:
            self.inputs.new_location.connect(new_location)

    @staticmethod
    def _spec():
        spec = Specification(description="""change the location of a field.""",
                             map_input_pin_spec={
                                 0 : PinSpecification(name = "field", type_names=["field"], optional=False, document=""""""), 
                                 1 : PinSpecification(name = "new_location", type_names=["string"], optional=False, document="""new location of the output field ex 'Nodal', 'ElementalNodal', 'Elemental'...""")},
                             map_output_pin_spec={
                                 0 : PinSpecification(name = "field", type_names=["field"], optional=False, document="""""")})
        return spec


    @staticmethod
    def default_config():
        return Operator.default_config(name = "change_location")

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsChangeLocation 
        """
        return super().inputs


    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluationg it

        Returns
        --------
        outputs : OutputsChangeLocation 
        """
        return super().outputs


#internal name: change_location
#scripting name: change_location
class InputsChangeLocation(_Inputs):
    """Intermediate class used to connect user inputs to change_location operator

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.utility.change_location()
      >>> my_field = dpf.Field()
      >>> op.inputs.field.connect(my_field)
      >>> my_new_location = str()
      >>> op.inputs.new_location.connect(my_new_location)
    """
    def __init__(self, op: Operator):
        super().__init__(change_location._spec().inputs, op)
        self._field = Input(change_location._spec().input_pin(0), 0, op, -1) 
        self._inputs.append(self._field)
        self._new_location = Input(change_location._spec().input_pin(1), 1, op, -1) 
        self._inputs.append(self._new_location)

    @property
    def field(self):
        """Allows to connect field input to the operator

        Parameters
        ----------
        my_field : Field, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.utility.change_location()
        >>> op.inputs.field.connect(my_field)
        >>> #or
        >>> op.inputs.field(my_field)

        """
        return self._field

    @property
    def new_location(self):
        """Allows to connect new_location input to the operator

        - pindoc: new location of the output field ex 'Nodal', 'ElementalNodal', 'Elemental'...

        Parameters
        ----------
        my_new_location : str, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.utility.change_location()
        >>> op.inputs.new_location.connect(my_new_location)
        >>> #or
        >>> op.inputs.new_location(my_new_location)

        """
        return self._new_location

class OutputsChangeLocation(_Outputs):
    """Intermediate class used to get outputs from change_location operator
      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.utility.change_location()
      >>> # Connect inputs : op.inputs. ...
      >>> result_field = op.outputs.field()
    """
    def __init__(self, op: Operator):
        super().__init__(change_location._spec().outputs, op)
        self._field = Output(change_location._spec().output_pin(0), 0, op) 
        self._outputs.append(self._field)

    @property
    def field(self):
        """Allows to get field output of the operator


        Returns
        ----------
        my_field : Field, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.utility.change_location()
        >>> # Connect inputs : op.inputs. ...
        >>> result_field = op.outputs.field() 
        """
        return self._field




"""
time_freq_provider
==================
"""
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs, _modify_output_spec_with_one_type
from ansys.dpf.core.operators.specification import PinSpecification, Specification

"""Operators from Ans.Dpf.Native plugin, from "metadata" category
"""

class time_freq_provider(Operator):
    """Read the time freq support from the results files contained in the streams or data sources.

      available inputs:
        - streams_container (StreamsContainer) (optional)
        - data_sources (DataSources)

      available outputs:
        - time_freq_support (TimeFreqSupport)

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> # Instantiate operator
      >>> op = dpf.operators.metadata.time_freq_provider()

      >>> # Make input connections
      >>> my_streams_container = dpf.StreamsContainer()
      >>> op.inputs.streams_container.connect(my_streams_container)
      >>> my_data_sources = dpf.DataSources()
      >>> op.inputs.data_sources.connect(my_data_sources)

      >>> # Instantiate operator and connect inputs in one line
      >>> op = dpf.operators.metadata.time_freq_provider(streams_container=my_streams_container,data_sources=my_data_sources)

      >>> # Get output data
      >>> result_time_freq_support = op.outputs.time_freq_support()"""
    def __init__(self, streams_container=None, data_sources=None, config=None, server=None):
        super().__init__(name="TimeFreqSupportProvider", config = config, server = server)
        self._inputs = InputsTimeFreqProvider(self)
        self._outputs = OutputsTimeFreqProvider(self)
        if streams_container !=None:
            self.inputs.streams_container.connect(streams_container)
        if data_sources !=None:
            self.inputs.data_sources.connect(data_sources)

    @staticmethod
    def _spec():
        spec = Specification(description="""Read the time freq support from the results files contained in the streams or data sources.""",
                             map_input_pin_spec={
                                 3 : PinSpecification(name = "streams_container", type_names=["streams_container"], optional=True, document="""streams (result file container) (optional)"""), 
                                 4 : PinSpecification(name = "data_sources", type_names=["data_sources"], optional=False, document="""if the stream is null then we need to get the file path from the data sources""")},
                             map_output_pin_spec={
                                 0 : PinSpecification(name = "time_freq_support", type_names=["time_freq_support"], optional=False, document="""""")})
        return spec


    @staticmethod
    def default_config():
        return Operator.default_config(name = "TimeFreqSupportProvider")

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsTimeFreqProvider 
        """
        return super().inputs


    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluationg it

        Returns
        --------
        outputs : OutputsTimeFreqProvider 
        """
        return super().outputs


#internal name: TimeFreqSupportProvider
#scripting name: time_freq_provider
class InputsTimeFreqProvider(_Inputs):
    """Intermediate class used to connect user inputs to time_freq_provider operator

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.metadata.time_freq_provider()
      >>> my_streams_container = dpf.StreamsContainer()
      >>> op.inputs.streams_container.connect(my_streams_container)
      >>> my_data_sources = dpf.DataSources()
      >>> op.inputs.data_sources.connect(my_data_sources)
    """
    def __init__(self, op: Operator):
        super().__init__(time_freq_provider._spec().inputs, op)
        self._streams_container = Input(time_freq_provider._spec().input_pin(3), 3, op, -1) 
        self._inputs.append(self._streams_container)
        self._data_sources = Input(time_freq_provider._spec().input_pin(4), 4, op, -1) 
        self._inputs.append(self._data_sources)

    @property
    def streams_container(self):
        """Allows to connect streams_container input to the operator

        - pindoc: streams (result file container) (optional)

        Parameters
        ----------
        my_streams_container : StreamsContainer, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.metadata.time_freq_provider()
        >>> op.inputs.streams_container.connect(my_streams_container)
        >>> #or
        >>> op.inputs.streams_container(my_streams_container)

        """
        return self._streams_container

    @property
    def data_sources(self):
        """Allows to connect data_sources input to the operator

        - pindoc: if the stream is null then we need to get the file path from the data sources

        Parameters
        ----------
        my_data_sources : DataSources, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.metadata.time_freq_provider()
        >>> op.inputs.data_sources.connect(my_data_sources)
        >>> #or
        >>> op.inputs.data_sources(my_data_sources)

        """
        return self._data_sources

class OutputsTimeFreqProvider(_Outputs):
    """Intermediate class used to get outputs from time_freq_provider operator
      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.metadata.time_freq_provider()
      >>> # Connect inputs : op.inputs. ...
      >>> result_time_freq_support = op.outputs.time_freq_support()
    """
    def __init__(self, op: Operator):
        super().__init__(time_freq_provider._spec().outputs, op)
        self._time_freq_support = Output(time_freq_provider._spec().output_pin(0), 0, op) 
        self._outputs.append(self._time_freq_support)

    @property
    def time_freq_support(self):
        """Allows to get time_freq_support output of the operator


        Returns
        ----------
        my_time_freq_support : TimeFreqSupport, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.metadata.time_freq_provider()
        >>> # Connect inputs : op.inputs. ...
        >>> result_time_freq_support = op.outputs.time_freq_support() 
        """
        return self._time_freq_support




"""
add_constant
============
"""
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs, _modify_output_spec_with_one_type
from ansys.dpf.core.operators.specification import PinSpecification, Specification

"""Operators from Ans.Dpf.Native plugin, from "math" category
"""

class add_constant(Operator):
    """Computes the sum of a field (in 0) and a scalar (in 1).

      available inputs:
        - field (Field, FieldsContainer)
        - ponderation (float, list)

      available outputs:
        - field (Field)

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> # Instantiate operator
      >>> op = dpf.operators.math.add_constant()

      >>> # Make input connections
      >>> my_field = dpf.Field()
      >>> op.inputs.field.connect(my_field)
      >>> my_ponderation = float()
      >>> op.inputs.ponderation.connect(my_ponderation)

      >>> # Instantiate operator and connect inputs in one line
      >>> op = dpf.operators.math.add_constant(field=my_field,ponderation=my_ponderation)

      >>> # Get output data
      >>> result_field = op.outputs.field()"""
    def __init__(self, field=None, ponderation=None, config=None, server=None):
        super().__init__(name="add_constant", config = config, server = server)
        self._inputs = InputsAddConstant(self)
        self._outputs = OutputsAddConstant(self)
        if field !=None:
            self.inputs.field.connect(field)
        if ponderation !=None:
            self.inputs.ponderation.connect(ponderation)

    @staticmethod
    def _spec():
        spec = Specification(description="""Computes the sum of a field (in 0) and a scalar (in 1).""",
                             map_input_pin_spec={
                                 0 : PinSpecification(name = "field", type_names=["field","fields_container"], optional=False, document="""field or fields container with only one field is expected"""), 
                                 1 : PinSpecification(name = "ponderation", type_names=["double","vector<double>"], optional=False, document="""double or vector of double""")},
                             map_output_pin_spec={
                                 0 : PinSpecification(name = "field", type_names=["field"], optional=False, document="""""")})
        return spec


    @staticmethod
    def default_config():
        return Operator.default_config(name = "add_constant")

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsAddConstant 
        """
        return super().inputs


    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluationg it

        Returns
        --------
        outputs : OutputsAddConstant 
        """
        return super().outputs


#internal name: add_constant
#scripting name: add_constant
class InputsAddConstant(_Inputs):
    """Intermediate class used to connect user inputs to add_constant operator

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.math.add_constant()
      >>> my_field = dpf.Field()
      >>> op.inputs.field.connect(my_field)
      >>> my_ponderation = float()
      >>> op.inputs.ponderation.connect(my_ponderation)
    """
    def __init__(self, op: Operator):
        super().__init__(add_constant._spec().inputs, op)
        self._field = Input(add_constant._spec().input_pin(0), 0, op, -1) 
        self._inputs.append(self._field)
        self._ponderation = Input(add_constant._spec().input_pin(1), 1, op, -1) 
        self._inputs.append(self._ponderation)

    @property
    def field(self):
        """Allows to connect field input to the operator

        - pindoc: field or fields container with only one field is expected

        Parameters
        ----------
        my_field : Field, FieldsContainer, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.math.add_constant()
        >>> op.inputs.field.connect(my_field)
        >>> #or
        >>> op.inputs.field(my_field)

        """
        return self._field

    @property
    def ponderation(self):
        """Allows to connect ponderation input to the operator

        - pindoc: double or vector of double

        Parameters
        ----------
        my_ponderation : float, list, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.math.add_constant()
        >>> op.inputs.ponderation.connect(my_ponderation)
        >>> #or
        >>> op.inputs.ponderation(my_ponderation)

        """
        return self._ponderation

class OutputsAddConstant(_Outputs):
    """Intermediate class used to get outputs from add_constant operator
      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.math.add_constant()
      >>> # Connect inputs : op.inputs. ...
      >>> result_field = op.outputs.field()
    """
    def __init__(self, op: Operator):
        super().__init__(add_constant._spec().outputs, op)
        self._field = Output(add_constant._spec().output_pin(0), 0, op) 
        self._outputs.append(self._field)

    @property
    def field(self):
        """Allows to get field output of the operator


        Returns
        ----------
        my_field : Field, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.math.add_constant()
        >>> # Connect inputs : op.inputs. ...
        >>> result_field = op.outputs.field() 
        """
        return self._field




"""
img_part
========
"""
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs, _modify_output_spec_with_one_type
from ansys.dpf.core.operators.specification import PinSpecification, Specification

"""Operators from Ans.Dpf.Native plugin, from "math" category
"""

class img_part(Operator):
    """Extracts element-wise imaginary part of field containers containing complex fields.

      available inputs:
        - fields_container (FieldsContainer)

      available outputs:
        - fields_container (FieldsContainer)

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> # Instantiate operator
      >>> op = dpf.operators.math.img_part()

      >>> # Make input connections
      >>> my_fields_container = dpf.FieldsContainer()
      >>> op.inputs.fields_container.connect(my_fields_container)

      >>> # Instantiate operator and connect inputs in one line
      >>> op = dpf.operators.math.img_part(fields_container=my_fields_container)

      >>> # Get output data
      >>> result_fields_container = op.outputs.fields_container()"""
    def __init__(self, fields_container=None, config=None, server=None):
        super().__init__(name="img_part", config = config, server = server)
        self._inputs = InputsImgPart(self)
        self._outputs = OutputsImgPart(self)
        if fields_container !=None:
            self.inputs.fields_container.connect(fields_container)

    @staticmethod
    def _spec():
        spec = Specification(description="""Extracts element-wise imaginary part of field containers containing complex fields.""",
                             map_input_pin_spec={
                                 0 : PinSpecification(name = "fields_container", type_names=["fields_container"], optional=False, document="""""")},
                             map_output_pin_spec={
                                 0 : PinSpecification(name = "fields_container", type_names=["fields_container"], optional=False, document="""""")})
        return spec


    @staticmethod
    def default_config():
        return Operator.default_config(name = "img_part")

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsImgPart 
        """
        return super().inputs


    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluationg it

        Returns
        --------
        outputs : OutputsImgPart 
        """
        return super().outputs


#internal name: img_part
#scripting name: img_part
class InputsImgPart(_Inputs):
    """Intermediate class used to connect user inputs to img_part operator

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.math.img_part()
      >>> my_fields_container = dpf.FieldsContainer()
      >>> op.inputs.fields_container.connect(my_fields_container)
    """
    def __init__(self, op: Operator):
        super().__init__(img_part._spec().inputs, op)
        self._fields_container = Input(img_part._spec().input_pin(0), 0, op, -1) 
        self._inputs.append(self._fields_container)

    @property
    def fields_container(self):
        """Allows to connect fields_container input to the operator

        Parameters
        ----------
        my_fields_container : FieldsContainer, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.math.img_part()
        >>> op.inputs.fields_container.connect(my_fields_container)
        >>> #or
        >>> op.inputs.fields_container(my_fields_container)

        """
        return self._fields_container

class OutputsImgPart(_Outputs):
    """Intermediate class used to get outputs from img_part operator
      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.math.img_part()
      >>> # Connect inputs : op.inputs. ...
      >>> result_fields_container = op.outputs.fields_container()
    """
    def __init__(self, op: Operator):
        super().__init__(img_part._spec().outputs, op)
        self._fields_container = Output(img_part._spec().output_pin(0), 0, op) 
        self._outputs.append(self._fields_container)

    @property
    def fields_container(self):
        """Allows to get fields_container output of the operator


        Returns
        ----------
        my_fields_container : FieldsContainer, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.math.img_part()
        >>> # Connect inputs : op.inputs. ...
        >>> result_fields_container = op.outputs.fields_container() 
        """
        return self._fields_container




"""
to_elemental_fc
===============
"""
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs, _modify_output_spec_with_one_type
from ansys.dpf.core.operators.specification import PinSpecification, Specification

"""Operators from Ans.Dpf.FEMutils plugin, from "averaging" category
"""

class to_elemental_fc(Operator):
    """Transform input fields into Elemental fields using an averaging process, result is computed on a given elements scoping.

      available inputs:
        - fields_container (FieldsContainer)
        - mesh (MeshedRegion) (optional)
        - mesh_scoping (Scoping) (optional)
        - smoothen_values (bool) (optional)
        - collapse_shell_layers (bool) (optional)

      available outputs:
        - fields_container (FieldsContainer)

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> # Instantiate operator
      >>> op = dpf.operators.averaging.to_elemental_fc()

      >>> # Make input connections
      >>> my_fields_container = dpf.FieldsContainer()
      >>> op.inputs.fields_container.connect(my_fields_container)
      >>> my_mesh = dpf.MeshedRegion()
      >>> op.inputs.mesh.connect(my_mesh)
      >>> my_mesh_scoping = dpf.Scoping()
      >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
      >>> my_smoothen_values = bool()
      >>> op.inputs.smoothen_values.connect(my_smoothen_values)
      >>> my_collapse_shell_layers = bool()
      >>> op.inputs.collapse_shell_layers.connect(my_collapse_shell_layers)

      >>> # Instantiate operator and connect inputs in one line
      >>> op = dpf.operators.averaging.to_elemental_fc(fields_container=my_fields_container,mesh=my_mesh,mesh_scoping=my_mesh_scoping,smoothen_values=my_smoothen_values,collapse_shell_layers=my_collapse_shell_layers)

      >>> # Get output data
      >>> result_fields_container = op.outputs.fields_container()"""
    def __init__(self, fields_container=None, mesh=None, mesh_scoping=None, smoothen_values=None, collapse_shell_layers=None, config=None, server=None):
        super().__init__(name="to_elemental_fc", config = config, server = server)
        self._inputs = InputsToElementalFc(self)
        self._outputs = OutputsToElementalFc(self)
        if fields_container !=None:
            self.inputs.fields_container.connect(fields_container)
        if mesh !=None:
            self.inputs.mesh.connect(mesh)
        if mesh_scoping !=None:
            self.inputs.mesh_scoping.connect(mesh_scoping)
        if smoothen_values !=None:
            self.inputs.smoothen_values.connect(smoothen_values)
        if collapse_shell_layers !=None:
            self.inputs.collapse_shell_layers.connect(collapse_shell_layers)

    @staticmethod
    def _spec():
        spec = Specification(description="""Transform input fields into Elemental fields using an averaging process, result is computed on a given elements scoping.""",
                             map_input_pin_spec={
                                 0 : PinSpecification(name = "fields_container", type_names=["fields_container"], optional=False, document=""""""), 
                                 1 : PinSpecification(name = "mesh", type_names=["abstract_meshed_region"], optional=True, document=""""""), 
                                 3 : PinSpecification(name = "mesh_scoping", type_names=["scoping"], optional=True, document=""""""), 
                                 7 : PinSpecification(name = "smoothen_values", type_names=["bool"], optional=True, document="""if it is set to true, elemental nodal fields are first averaged on nodes and then averaged on elements (default is false)"""), 
                                 10 : PinSpecification(name = "collapse_shell_layers", type_names=["bool"], optional=True, document="""if true shell layers are averaged as well (default is false)""")},
                             map_output_pin_spec={
                                 0 : PinSpecification(name = "fields_container", type_names=["fields_container"], optional=False, document="""""")})
        return spec


    @staticmethod
    def default_config():
        return Operator.default_config(name = "to_elemental_fc")

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsToElementalFc 
        """
        return super().inputs


    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluationg it

        Returns
        --------
        outputs : OutputsToElementalFc 
        """
        return super().outputs


#internal name: to_elemental_fc
#scripting name: to_elemental_fc
class InputsToElementalFc(_Inputs):
    """Intermediate class used to connect user inputs to to_elemental_fc operator

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.averaging.to_elemental_fc()
      >>> my_fields_container = dpf.FieldsContainer()
      >>> op.inputs.fields_container.connect(my_fields_container)
      >>> my_mesh = dpf.MeshedRegion()
      >>> op.inputs.mesh.connect(my_mesh)
      >>> my_mesh_scoping = dpf.Scoping()
      >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
      >>> my_smoothen_values = bool()
      >>> op.inputs.smoothen_values.connect(my_smoothen_values)
      >>> my_collapse_shell_layers = bool()
      >>> op.inputs.collapse_shell_layers.connect(my_collapse_shell_layers)
    """
    def __init__(self, op: Operator):
        super().__init__(to_elemental_fc._spec().inputs, op)
        self._fields_container = Input(to_elemental_fc._spec().input_pin(0), 0, op, -1) 
        self._inputs.append(self._fields_container)
        self._mesh = Input(to_elemental_fc._spec().input_pin(1), 1, op, -1) 
        self._inputs.append(self._mesh)
        self._mesh_scoping = Input(to_elemental_fc._spec().input_pin(3), 3, op, -1) 
        self._inputs.append(self._mesh_scoping)
        self._smoothen_values = Input(to_elemental_fc._spec().input_pin(7), 7, op, -1) 
        self._inputs.append(self._smoothen_values)
        self._collapse_shell_layers = Input(to_elemental_fc._spec().input_pin(10), 10, op, -1) 
        self._inputs.append(self._collapse_shell_layers)

    @property
    def fields_container(self):
        """Allows to connect fields_container input to the operator

        Parameters
        ----------
        my_fields_container : FieldsContainer, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.averaging.to_elemental_fc()
        >>> op.inputs.fields_container.connect(my_fields_container)
        >>> #or
        >>> op.inputs.fields_container(my_fields_container)

        """
        return self._fields_container

    @property
    def mesh(self):
        """Allows to connect mesh input to the operator

        Parameters
        ----------
        my_mesh : MeshedRegion, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.averaging.to_elemental_fc()
        >>> op.inputs.mesh.connect(my_mesh)
        >>> #or
        >>> op.inputs.mesh(my_mesh)

        """
        return self._mesh

    @property
    def mesh_scoping(self):
        """Allows to connect mesh_scoping input to the operator

        Parameters
        ----------
        my_mesh_scoping : Scoping, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.averaging.to_elemental_fc()
        >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
        >>> #or
        >>> op.inputs.mesh_scoping(my_mesh_scoping)

        """
        return self._mesh_scoping

    @property
    def smoothen_values(self):
        """Allows to connect smoothen_values input to the operator

        - pindoc: if it is set to true, elemental nodal fields are first averaged on nodes and then averaged on elements (default is false)

        Parameters
        ----------
        my_smoothen_values : bool, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.averaging.to_elemental_fc()
        >>> op.inputs.smoothen_values.connect(my_smoothen_values)
        >>> #or
        >>> op.inputs.smoothen_values(my_smoothen_values)

        """
        return self._smoothen_values

    @property
    def collapse_shell_layers(self):
        """Allows to connect collapse_shell_layers input to the operator

        - pindoc: if true shell layers are averaged as well (default is false)

        Parameters
        ----------
        my_collapse_shell_layers : bool, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.averaging.to_elemental_fc()
        >>> op.inputs.collapse_shell_layers.connect(my_collapse_shell_layers)
        >>> #or
        >>> op.inputs.collapse_shell_layers(my_collapse_shell_layers)

        """
        return self._collapse_shell_layers

class OutputsToElementalFc(_Outputs):
    """Intermediate class used to get outputs from to_elemental_fc operator
      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.averaging.to_elemental_fc()
      >>> # Connect inputs : op.inputs. ...
      >>> result_fields_container = op.outputs.fields_container()
    """
    def __init__(self, op: Operator):
        super().__init__(to_elemental_fc._spec().outputs, op)
        self._fields_container = Output(to_elemental_fc._spec().output_pin(0), 0, op) 
        self._outputs.append(self._fields_container)

    @property
    def fields_container(self):
        """Allows to get fields_container output of the operator


        Returns
        ----------
        my_fields_container : FieldsContainer, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.averaging.to_elemental_fc()
        >>> # Connect inputs : op.inputs. ...
        >>> result_fields_container = op.outputs.fields_container() 
        """
        return self._fields_container




"""
principal_invariants
====================
"""
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs, _modify_output_spec_with_one_type
from ansys.dpf.core.operators.specification import PinSpecification, Specification

"""Operators from Ans.Dpf.FEMutils plugin, from "invariant" category
"""

class principal_invariants(Operator):
    """Computes the element-wise eigen values of a tensor field

      available inputs:
        - field (Field)

      available outputs:
        - field_eig_1 (Field)
        - field_eig_2 (Field)
        - field_eig_3 (Field)

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> # Instantiate operator
      >>> op = dpf.operators.invariant.principal_invariants()

      >>> # Make input connections
      >>> my_field = dpf.Field()
      >>> op.inputs.field.connect(my_field)

      >>> # Instantiate operator and connect inputs in one line
      >>> op = dpf.operators.invariant.principal_invariants(field=my_field)

      >>> # Get output data
      >>> result_field_eig_1 = op.outputs.field_eig_1()
      >>> result_field_eig_2 = op.outputs.field_eig_2()
      >>> result_field_eig_3 = op.outputs.field_eig_3()"""
    def __init__(self, field=None, config=None, server=None):
        super().__init__(name="invariants", config = config, server = server)
        self._inputs = InputsPrincipalInvariants(self)
        self._outputs = OutputsPrincipalInvariants(self)
        if field !=None:
            self.inputs.field.connect(field)

    @staticmethod
    def _spec():
        spec = Specification(description="""Computes the element-wise eigen values of a tensor field""",
                             map_input_pin_spec={
                                 0 : PinSpecification(name = "field", type_names=["field"], optional=False, document="""""")},
                             map_output_pin_spec={
                                 0 : PinSpecification(name = "field_eig_1", type_names=["field"], optional=False, document="""first eigen value field"""), 
                                 1 : PinSpecification(name = "field_eig_2", type_names=["field"], optional=False, document="""second eigen value field"""), 
                                 2 : PinSpecification(name = "field_eig_3", type_names=["field"], optional=False, document="""third eigen value field""")})
        return spec


    @staticmethod
    def default_config():
        return Operator.default_config(name = "invariants")

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsPrincipalInvariants 
        """
        return super().inputs


    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluationg it

        Returns
        --------
        outputs : OutputsPrincipalInvariants 
        """
        return super().outputs


#internal name: invariants
#scripting name: principal_invariants
class InputsPrincipalInvariants(_Inputs):
    """Intermediate class used to connect user inputs to principal_invariants operator

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.invariant.principal_invariants()
      >>> my_field = dpf.Field()
      >>> op.inputs.field.connect(my_field)
    """
    def __init__(self, op: Operator):
        super().__init__(principal_invariants._spec().inputs, op)
        self._field = Input(principal_invariants._spec().input_pin(0), 0, op, -1) 
        self._inputs.append(self._field)

    @property
    def field(self):
        """Allows to connect field input to the operator

        Parameters
        ----------
        my_field : Field, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.invariant.principal_invariants()
        >>> op.inputs.field.connect(my_field)
        >>> #or
        >>> op.inputs.field(my_field)

        """
        return self._field

class OutputsPrincipalInvariants(_Outputs):
    """Intermediate class used to get outputs from principal_invariants operator
      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.invariant.principal_invariants()
      >>> # Connect inputs : op.inputs. ...
      >>> result_field_eig_1 = op.outputs.field_eig_1()
      >>> result_field_eig_2 = op.outputs.field_eig_2()
      >>> result_field_eig_3 = op.outputs.field_eig_3()
    """
    def __init__(self, op: Operator):
        super().__init__(principal_invariants._spec().outputs, op)
        self._field_eig_1 = Output(principal_invariants._spec().output_pin(0), 0, op) 
        self._outputs.append(self._field_eig_1)
        self._field_eig_2 = Output(principal_invariants._spec().output_pin(1), 1, op) 
        self._outputs.append(self._field_eig_2)
        self._field_eig_3 = Output(principal_invariants._spec().output_pin(2), 2, op) 
        self._outputs.append(self._field_eig_3)

    @property
    def field_eig_1(self):
        """Allows to get field_eig_1 output of the operator


        - pindoc: first eigen value field

        Returns
        ----------
        my_field_eig_1 : Field, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.invariant.principal_invariants()
        >>> # Connect inputs : op.inputs. ...
        >>> result_field_eig_1 = op.outputs.field_eig_1() 
        """
        return self._field_eig_1

    @property
    def field_eig_2(self):
        """Allows to get field_eig_2 output of the operator


        - pindoc: second eigen value field

        Returns
        ----------
        my_field_eig_2 : Field, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.invariant.principal_invariants()
        >>> # Connect inputs : op.inputs. ...
        >>> result_field_eig_2 = op.outputs.field_eig_2() 
        """
        return self._field_eig_2

    @property
    def field_eig_3(self):
        """Allows to get field_eig_3 output of the operator


        - pindoc: third eigen value field

        Returns
        ----------
        my_field_eig_3 : Field, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.invariant.principal_invariants()
        >>> # Connect inputs : op.inputs. ...
        >>> result_field_eig_3 = op.outputs.field_eig_3() 
        """
        return self._field_eig_3

